Crate satchel_macro

Crate satchel_macro 

Procedural attribute macros used by the satchel crate to register tests and benchmarks.

Do not use this crate directly, but through the re-exports in the satchel crate.

Attribute Macros

bench
Please use this macro via the re-export in satchel.
test
Please use this macro via the re-export in satchel.